==> facio_design_system-1.3.0.tar.gz: lib/src/components/buttons/medium_outlined_button.dart <==
import 'package:facio_design_system/components.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class MediumOutlinedButton extends StatelessWidget {
  const MediumOutlinedButton({
    final Key key,
    @required final String title,
    final VoidCallback onPressed,
    final bool isEnabled = true,
  })  : assert(title != null),
        assert(isEnabled != null),
        _isEnabled = isEnabled,
        _key = key,
        _title = title,
        _onPressed = onPressed;

  final Key _key;
  final bool _isEnabled;
  final String _title;
  final VoidCallback _onPressed;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: Sizes.baseSingle),
      child: OutlineButton(
        key: _key,
        onPressed: _isEnabled ? _onPressed : null,
        borderSide: const BorderSide(
          color: OutlinedButtonStyles.defaultBorderColor,
          width: OutlinedButtonStyles.borderWidth,
        ),
        splashColor: Colors.transparent,
        highlightColor: Colors.transparent,
        highlightedBorderColor: OutlinedButtonStyles.pressedBorderColor,
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(OutlinedButtonStyles.sizeSmallBorderRadius),
        ),
        child: Text(
          _title,
          textAlign: TextAlign.center,
          style: _isEnabled ? TextStyles.button : TextStyles.button.copyWith(color: OutlinedButtonStyles.disabledColor),
        ),
      ),
    );
  }
}

==> facio_design_system-2.0.0.tar.gz: lib/src/components/buttons/medium_outlined_button.dart <==
import 'package:facio_design_system/components.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class MediumOutlinedButton extends StatelessWidget {
  const MediumOutlinedButton({
    final Key key,
    @required final String title,
    final VoidCallback onPressed,
    final bool isEnabled = true,
  })  : assert(title != null),
        assert(isEnabled != null),
        _isEnabled = isEnabled,
        _key = key,
        _title = title,
        _onPressed = onPressed;

  final Key _key;
  final bool _isEnabled;
  final String _title;
  final VoidCallback _onPressed;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: Sizes.baseSingle),
      child: OutlineButton(
        key: _key,
        onPressed: _isEnabled ? _onPressed : null,
        borderSide: const BorderSide(
          color: OutlinedButtonStyles.defaultBorderColor,
          width: OutlinedButtonStyles.borderWidth,
        ),
        splashColor: Colors.transparent,
        highlightColor: Colors.transparent,
        highlightedBorderColor: OutlinedButtonStyles.pressedBorderColor,
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(ButtonStyles.sizeSmallBorderRadius),
        ),
        child: Text(
          _title,
          textAlign: TextAlign.center,
          style: _isEnabled ? TextStyles.button : TextStyles.button.copyWith(color: OutlinedButtonStyles.disabledColor),
        ),
      ),
    );
  }
}
